from django import forms
from django.apps import apps as django_apps
from django.contrib import messages
from django.core.management.color import color_style
from django.forms.forms import Form
from django.http.response import HttpResponseRedirect
from django.urls.base import reverse
from edc_dashboard.view_mixins import EdcViewMixin
from edc_dashboard.views import DashboardView as BaseDashboardView

style = color_style()


class Dispense:
    def __init__(self, **kwargs):
        pass


class DispenseForm(Form):

    medications = forms.MultipleChoiceField()


app_config = django_apps.get_app_config("edc_pharmacy_dashboard")


# class DispenseViewMixin(DispensePrintLabelMixin):
class DispenseViewMixin:

    dispense_cls = Dispense
    prescription_model = "edc_pharmacy.prescription"

    def get_success_url(self):
        return "/"

    def post(self, request, *args, **kwargs):
        subject_identifier = kwargs.get("subject_identifier")
        prescriptions = []

        error_message = None
        for key in self.request.POST:
            if key.startswith("med"):
                p = self.prescription_model_cls.objects.get(
                    id=self.request.POST.get(key)
                )
                if not p.dispense_appointment.is_dispensed:
                    error_message = "Dispensing is required before printing labels."
                    break
                prescriptions.append(p)
        if not error_message:
            action = self.request.POST.get("action")
            dispense = self.dispense_cls(
                prescriptions=prescriptions, action=action)
            if dispense.printed_labels:
                for label in dispense.printed_labels:
                    medication = label.get("medication")
                    subject_identifier = label.get("subject_identifier")
                    msg = f" Printed {medication} for {subject_identifier}."
                    messages.add_message(request, messages.SUCCESS, msg)
            else:
                msg = f"Nothing selected for {subject_identifier} FFFF."
                messages.add_message(request, messages.ERROR, msg)
        else:
            messages.add_message(request, messages.WARNING, error_message)
        url = reverse(
            app_config.appointment_listboard_url_name,
            kwargs={"subject_identifier": subject_identifier},
        )
        return HttpResponseRedirect(url)

    @property
    def prescription_model_cls(self):
        return django_apps.get_model(self.prescription_model)


class DispensingView(DispenseViewMixin, EdcViewMixin, BaseDashboardView):
    app_config_name = "edc_pharmacy"
    dashboard_url_name = "subject_dashboard_url"



from edc_auth.site_auths import site_auths
from edc_auth.utils import remove_default_model_permissions_from_edc_permissions

site_auths.add_post_update_func(
    "edc_pharmacy_dashboard", remove_default_model_permissions_from_edc_permissions
)



from edc_listboard.filters import ListboardFilter, ListboardViewFilters


class AppointmentListboardViewFilters(ListboardViewFilters):

    all = ListboardFilter(name="all", position=0, label="All", lookup={})

    not_dispensed = ListboardFilter(
        name="control", position=10, label="Control Arm", lookup={"rx": True}
    )

    dispensed = ListboardFilter(
        name="single_dose", label="Single Dose", position=20, lookup={"rx": True}
    )



# from django.apps import apps as django_apps
# from django.contrib.auth.decorators import login_required
# from django.utils.decorators import method_decorator
#
# from ...model_wrappers import WorklistModelWrapper
# from ..listboard_filters import WorklistListboardViewFilters
# from .base_listboard import BaseListboardView
#
#
# app_config = django_apps.get_app_config('edc_pharmacy_dashboard')
# edc_pharmacy_app_config = django_apps.get_app_config('edc_pharmacy')
#
#
# class WorklistListboardView(BaseListboardView):
#
#     navbar_item_selected = 'worklist'
#
#     model = edc_pharmacy_app_config.worklist_model
#     model_wrapper_cls = WorklistModelWrapper
#     listboard_url_name = app_config.worklist_listboard_url_name
#     listboard_template_name = app_config.worklist_listboard_template_name
#     prescription_listboard_url_name = app_config.prescription_listboard_url_name
#     show_all = True
#     listboard_view_filters = WorklistListboardViewFilters()
#
#     def get_context_data(self, **kwargs):
#         context = super().get_context_data(**kwargs)
#         context.update(
#             listboard_url_name=self.listboard_url_name,
#             prescription_listboard_url_name=self.prescription_listboard_url_name)
#         return context
#
#     @method_decorator(login_required)
#     def dispatch(self, *args, **kwargs):
#         return super().dispatch(*args, **kwargs)
#
#     def get_queryset_filter_options(self, request, *args, **kwargs):
#         options = super().get_queryset_filter_options(request, *args, **kwargs)
#         return options



# from .approve_prescription import ApprovePrescriptionView
# from .dispense_print_label_action_view import (
#    DispensePrintLabelActionView, DispensePrintLabelMixin)
# from .dispensing_action_view import DispensingActionView



from django.urls.conf import path

from .views import HomeView, PrescribeListboardView

app_name = "edc_pharmacy_dashboard"

urlpatterns = [
    path(
        r"rx/prescribe/",
        PrescribeListboardView.as_view(),
        name="prescribe_listboard_url",
    ),
    path(
        r"rx/dispense/", PrescribeListboardView.as_view(), name="dispense_listboard_url"
    ),
    path("home/", HomeView.as_view(), name="home_url"),
    path("", HomeView.as_view(), name="home_url"),
]



from django.conf import settings
from edc_navbar import NavbarItem, site_navbars, Navbar

no_url_namespace = True if settings.APP_NAME == "edc_pharmacy_dashboard" else False

navbar = Navbar(name="pharmacy_dashboard")


navbar.append_item(
    NavbarItem(
        name="prescribe",
        title="prescribe",
        label="Prescribe",
        glyphicon="glyphicon-edit",
        no_url_namespace=no_url_namespace,
        codename="edc_navbar.nav_pharmacy_prescribe",
        url_name="edc_pharmacy_dashboard:prescribe_listboard_url",
    )
)

navbar.append_item(
    NavbarItem(
        name="dispense",
        title="dispense",
        label="Dispense",
        glyphicon="glyphicon-share",
        no_url_namespace=no_url_namespace,
        codename="edc_navbar.nav_pharmacy_dispense",
        url_name="edc_pharmacy_dashboard:dispense_listboard_url",
    )
)

navbar.append_item(
    NavbarItem(
        name="pharmacy",
        fa_icon="fa-medkit",
        no_url_namespace=no_url_namespace,
        codename="edc_navbar.nav_pharmacy_section",
        url_name="edc_pharmacy_dashboard:home_url",
    )
)


site_navbars.register(navbar)



from django.urls.base import reverse
from edc_dashboard.view_mixins import EdcViewMixin
from edc_listboard.view_mixins import ListboardFilterViewMixin
from edc_listboard.views import ListboardView

from ..mixins import ModelsViewMixin, UrlsViewMixin


class BaseListboardView(
    UrlsViewMixin,
    ListboardFilterViewMixin,
    ModelsViewMixin,
    EdcViewMixin,
    ListboardView,
):

    app_config_name = "edc_pharmacy_dashboard"
    navbar_name = "pharmacy"
    ordering = ["created"]

    search_url_name = None
    listboard_url_name = None
    listboard_template_name = None
    action_name = None
    form_action_url_name = None
    form_action_name = "form_action"
    form_action_selected_items_name = "selected_items"

    @property
    def search_form_url(self):
        url = reverse(
            self.search_url_name or self.listboard_url_name,
            kwargs=self.search_url_kwargs,
        )
        return f"{url}{self.querystring}"

    @property
    def search_url_kwargs(self):
        return self.url_kwargs

    @property
    def form_action_url_kwargs(self):
        return self.url_kwargs

    @property
    def url_kwargs(self):
        return {}

    @property
    def form_action_url(self):
        return reverse(
            self.form_action_url_name or self.listboard_url_name,
            kwargs=self.form_action_url_kwargs,
        )

    @property
    def listboard_url(self):
        return reverse(self.listboard_url_name, kwargs=self.url_kwargs)

    def get_template_names(self):
        return [self.listboard_template_name]

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        context.update(
            action_name=self.action_name,
            search_form_url=self.search_form_url,
            listboard_url=self.listboard_url,
            form_action_name=self.form_action_name,
            form_action_selected_items_name=self.form_action_selected_items_name,
            form_action_url=self.form_action_url,
        )
        return context



from django.apps import apps as django_apps
from edc_model_wrapper import ModelWrapper


app_config = django_apps.get_app_config("edc_pharmacy_dashboard")


class PrescriptionModelWrapper(ModelWrapper):

    model = "edc_pharmacy.prescription"
    next_url_name = app_config.prescribe_listboard_url_name
    querystring_attrs = ["subject_identifier"]

    @property
    def dispense_appt_describe(self):
        return None

    @property
    def subject_identifier(self):
        return self.object.subject_identifier

    @property
    def is_pending(self):
        return (
            self.dispense_appt_describe.is_next_pending_appointment()
            and not self.object.is_approved
        )



import re


class CleanSearchTermViewMixin:

    search_term_pattern = None

    def clean_search_term(self):
        search_term = super().clean_search_term()
        if search_term:
            search_terms = search_term.split("+")
            for index, term in enumerate(search_terms):
                if re.match(self.search_term_pattern, term):
                    search_terms[index] = "".join(term.split("_"))
            search_term = "+".join(search_terms)
        return search_term



from django.apps import apps as django_apps


app_name = "edc_pharmacy_dashboard"
app_config = django_apps.get_app_config(app_name)


class UrlsViewMixin:
    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        context.update(
            prescribe_listboard_url_name=app_config.prescribe_listboard_url_name
        )
        return context



from .clean_search_term_mixin import CleanSearchTermViewMixin
from .models_view_mixin import ModelsViewMixin
from .dispense_view_mixin import DispenseViewMixin
from .study_site_name_queryset_view_mixin import StudySiteNameQuerysetViewMixin
from .urls_view_mixin import UrlsViewMixin



from django.conf import settings

"""To customize any of the values below,
use settings.EDC_PHARMACY_DASHBOARD_URL_NAMES.
"""

dashboard_urls = {}

try:
    dashboard_urls.update(**settings.EDC_PHARMACY_DASHBOARD_URL_NAMES)
except AttributeError:
    pass



import urllib

from django.apps import apps as django_apps
from django.contrib import messages
from django.http.response import HttpResponseRedirect
from django.urls.base import reverse
from django.utils.text import slugify
from django.views.generic.base import TemplateView
from edc_dashboard.utils import get_bootstrap_version
from edc_dashboard.view_mixins import EdcViewMixin

# from edc_label.label import PrintLabelError
from edc_label.print_server import PrintServerSelectPrinterError

from ..mixins.models_view_mixin import ModelsViewMixin


class InvalidPostError(Exception):
    pass


app_name = "edc_pharmacy_dashboard"
app_config = django_apps.get_app_config(app_name)


class BaseActionView(EdcViewMixin, ModelsViewMixin, TemplateView):

    template_name = (
        f"edc_pharmacy_dashboard/bootstrap{get_bootstrap_version()}/home.html"
    )
    post_url_name = None
    app_config_name = "edc_pharmacy_dashboard"

    valid_form_actions = []
    redirect_querystring = {}
    form_action_selected_items_name = "selected_items"
    label_cls = None

    navbar_name = "pharma"

    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self._selected_items = []
        self.action = None

    @property
    def selected_items(self):
        """Returns a list of selected listboard items."""
        if not self._selected_items:
            self._selected_items = (
                self.request.POST.getlist(self.form_action_selected_items_name) or []
            )
        return self._selected_items

    @property
    def url_kwargs(self):
        """Returns the default dictionary to reverse the post url"""
        return {}

    @property
    def post_url(self):
        """Returns a URL."""
        return reverse(self.post_url_name, kwargs=self.url_kwargs)

    def post(self, request, *args, **kwargs):
        action = slugify(self.request.POST.get("action", "").lower())
        if action not in self.valid_form_actions:
            raise InvalidPostError("Invalid form action in POST. Got {}".format(action))
        else:
            self.action = action
        self.process_form_action()
        if self.redirect_querystring:
            return HttpResponseRedirect(
                self.post_url + "?" + urllib.parse.urlencode(self.redirect_querystring)
            )
        return HttpResponseRedirect(self.post_url)

    def process_form_action(self):
        """Override to conditionally handle the action POST attr."""
        pass

    def print_labels(self, pks=None):
        """Print labels for each selected item.

        See also: edc_pharma AppConfig
        """
        for pk in pks:
            try:
                label = self.label_cls(pk=pk, children_count=len(pks))
            except PrintServerSelectPrinterError as e:
                messages.error(
                    self.request, str(e), extra_tags="PrintServerSelectPrinterError"
                )
                break
            else:
                try:
                    result = label.print_label()
                except PrintLabelError as e:
                    messages.error(self.request, str(e))
                else:
                    messages.success(
                        self.request,
                        f"Printed {result.print_count}/{result.copies} {result.name} to "
                        f"{result.printer}. JobID {result.jobid}",
                    )



from edc_listboard.filters import ListboardFilter, ListboardViewFilters


class WorklistListboardViewFilters(ListboardViewFilters):

    all = ListboardFilter(name="all", position=0, label="All", lookup={})

    missed = ListboardFilter(
        name="control", position=10, label="Control Arm", lookup={"rx": True}
    )

    previous = ListboardFilter(
        name="single_dose",
        label="Single Dose",
        position=20,
        lookup={"singledose": True},
    )



# from django.apps import apps as django_apps
# from edc_model_wrapper import ModelWrapper
# from edc_pharmacy.models import Appointment
#
#
# app_config = django_apps.get_app_config('edc_pharmacy_dashboard')
# edc_pharma_app_config = django_apps.get_app_config('edc_pharma')
#
#
# class WorklistModelWrapper(ModelWrapper):
#
#     model = ''
#     next_url_name = app_config.worklist_listboard_url_name
#     querystring_attrs = ['subject_identifier']
#
#     @property
#     def subject_identifier(self):
#         return self.object.subject_identifier
#
#     @property
#     def appointments(self):
#         return [appt.is_dispensed for appt in Appointment.objects.filter(
#             subject_identifier=self.subject_identifier)]



from django.apps import apps as django_apps
from edc_model_wrapper import ModelWrapper

# from edc_pharmacy import AppointmentDescriber
# from edc_pharmacy.models import Prescription


app_config = django_apps.get_app_config("edc_pharmacy_dashboard")
# edc_pharma_app_config = django_apps.get_app_config('edc_pharmacy')


class AppointmentModelWrapper(ModelWrapper):

    model = "edc_pharmacy.dispenseappointment"
    next_url_name = app_config.appointment_listboard_url_name
    querystring_attrs = ["subject_identifier"]
    prescription_model = "edc_pharmacy.prescription"

    @property
    def dispense_appt_describe(self):
        return None
        # return AppointmentDescriber(dispense_appointment=self.object)

    @property
    def subject_identifier(self):
        return self.object.subject_identifier

    @property
    def prescriptions(self):
        model_cls = django_apps.get_model(self.prescription_model)
        return model_cls.objects.filter(dispense_appointment=self.object)

    @property
    def appointment_id(self):
        return str(self.object.id)

    @property
    def can_dispense_labels(self):
        if self.object.previous():
            return self.object.previous().is_dispensed
        return True



from django.apps import apps as django_apps
from django.contrib.auth.decorators import login_required
from django.http.response import HttpResponseRedirect
from django.utils.decorators import method_decorator

# from edc_pharmacy.dispense import Dispense

from ..dispense_print_label_mixin import DispensePrintLabelMixin
from .base_action_view import BaseActionView


app_config = django_apps.get_app_config("edc_pharmacy_dashboard")


class DispensePrintLabelActionView(DispensePrintLabelMixin, BaseActionView):

    post_url_name = app_config.appointment_listboard_url_name
    valid_form_actions = ["print_labels"]
    action_name = "pharma"

    # dispense_cls = Dispense

    @method_decorator(login_required)
    def dispatch(self, *args, **kwargs):
        return super().dispatch(*args, **kwargs)

    def get(self, request, *args, **kwargs):
        self.print_labels(request, **kwargs)
        return HttpResponseRedirect(self.post_url)



from django.apps import apps as django_apps


edc_pharmacy_app_config = django_apps.get_app_config("edc_pharmacy")


class ModelsViewMixin:
    @property
    def dispense_model(self):
        return django_apps.get_model(
            *edc_pharmacy_app_config.requisition_model.split(".")
        )



from edc_dashboard.utils import insert_bootstrap_version

dashboard_templates = dict(
    home_template="edc_pharmacy_dashboard/home.html",
    subject_review_listboard_template="edc_pharmacy_dashboard/subject_review_listboard.html",
)
dashboard_templates = insert_bootstrap_version(**dashboard_templates)



# from django.contrib import messages
# from edc_label.print_server import PrintServerSelectPrinterError
#
#
# class DispensePrintLabelMixin:
#
#     def prescriptions(self):
#         pass
#
#     def print_labels(self, request, **kwargs):
#         try:
#             dispense_print = self.dispense_cls(
#                 user=request.user,
#                 subject_identifier=kwargs.get('subject_identifier'),
#                 prescriptions=self.prescriptions,
#                 appointment_id=kwargs.get('appointment'))
#         except PrintServerSelectPrinterError as e:
#             messages.error(
#                 self.request,
#                 str(e), extra_tags='PrintServerSelectPrinterError')
#         else:
#             for label in dispense_print.printed_labels or []:
#                 description = label.get('medication')
#                 subject_identifier = label.get('subject_identifier')
#                 messages.success(
#                     self.request,
#                     f'Printed {description} for {subject_identifier}.')



from django.apps import apps as django_apps
from edc_device.constants import CLIENT, SERVER


class StudySiteNameQuerysetViewMixin:
    def get_queryset_filter_options(self, request, *args, **kwargs):
        options = super().get_queryset_filter_options(request, *args, **kwargs)
        app_config = django_apps.get_app_config("edc_pharmacy")
        if app_config.study_site_name:
            edc_device_app_config = django_apps.get_app_config("edc_device")
            if edc_device_app_config.device_role in [SERVER, CLIENT]:
                options.update(study_site_name=app_config.study_site_name)
        return options



from django.apps import apps as django_apps
from django.contrib.auth.decorators import login_required
from django.utils.decorators import method_decorator
from django.views.generic.base import TemplateView
from edc_dashboard.view_mixins import EdcViewMixin
from edc_navbar import NavbarViewMixin

app_config = django_apps.get_app_config("edc_pharmacy_dashboard")


class HomeView(EdcViewMixin, NavbarViewMixin, TemplateView):

    template_name = "edc_pharmacy_dashboard/home.html"
    base_template_name = app_config.base_template_name or "edc_dashboard/base.html"
    navbar_name = "pharmacy_dashboard"
    navbar_selected_item = "pharmacy"
    app_config_name = "edc_pharmacy_dashboard"

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        context.update(
            prescribe_listboard_url_name=app_config.prescribe_listboard_url_name,
            dispense_listboard_url_name=app_config.dispense_listboard_url_name,
        )
        return context

    @method_decorator(login_required)
    def dispatch(self, *args, **kwargs):
        return super().dispatch(*args, **kwargs)



from django.apps import apps as django_apps
from django.contrib.auth.decorators import login_required
from django.utils.decorators import method_decorator
from edc_navbar import NavbarViewMixin

from ...model_wrappers import PrescriptionModelWrapper
from ..listboard_filters import PrescriptionListboardViewFilters
from .base_listboard import BaseListboardView

app_config = django_apps.get_app_config("edc_pharmacy_dashboard")


class PrescribeListboardView(NavbarViewMixin, BaseListboardView):

    navbar_selected_item = "prescribe"
    navbar_name = "pharmacy_dashboard"

    listboard_template_name = app_config.prescribe_listboard_template_name
    listboard_url_name = app_config.prescribe_listboard_url_name
    listboard_view_filters = PrescriptionListboardViewFilters()

    model = PrescriptionModelWrapper.model
    model_wrapper_cls = PrescriptionModelWrapper

    show_all = True

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        context.update(listboard_url_name=self.listboard_url_name)
        return context

    @method_decorator(login_required)
    def dispatch(self, *args, **kwargs):
        return super().dispatch(*args, **kwargs)

    def get_queryset_filter_options(self, request, *args, **kwargs):
        options = super().get_queryset_filter_options(request, *args, **kwargs)
        if kwargs.get("q"):
            options.update(subject_identifier=kwargs.get("q"))
        return options



import re

from edc_constants.constants import UUID_PATTERN


class DispenseViewMixin:
    @property
    def selected_items(self):
        if not self._selected_items:
            for pk in self.request.POST.getlist(self.form_action_selected_items_name):
                if re.match(UUID_PATTERN, str(pk)):
                    self._selected_items.append(pk)
        return self._selected_items

    @property
    def dispenses(self):
        return self.selected_items



# from edc_pharmacy.dispense import DispenseAction, MedicationNotApprovedError
from django.apps import apps as django_apps

# from django.contrib import messages
from django.contrib.auth.decorators import login_required
from django.utils.decorators import method_decorator

from .base_action_view import BaseActionView


app_config = django_apps.get_app_config("edc_pharmacy_dashboard")
# edc_pharma_app_config = django_apps.get_app_config('edc_pharma')


class DispensingActionView(BaseActionView):

    post_url_name = app_config.appointment_listboard_url_name
    listboard_url_name = app_config.appointment_listboard_url_name
    valid_form_actions = ["dispensing"]
    prescription_model = "edc_pharmacy.prescription"

    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self._selected_manifest = None

    @method_decorator(login_required)
    def dispatch(self, *args, **kwargs):
        return super().dispatch(*args, **kwargs)

    def process_form_action(self):
        if self.action == "dispensing":
            self.dispensing()

    def dispensing(self):
        """Adds the selected items to the selected manifest.
        """
        return None


#         if not self.selected_items:
#             message = ('Nothing to do. No items have been selected.')
#             messages.warning(self.request, message)
#         else:
#             dispensed = 0
#             for selected_item in self.selected_items:
#                 try:
#                     DispenseAction(appointment_id=selected_item)
#                 except MedicationNotApprovedError as e:
#                     message = e
#                     break
#                 dispensed = dispensed + 1
#             if dispensed > 0:
#                 message = (
#                     '{} items have been dispensed.'.format(
#                         dispensed))
#                 messages.success(self.request, message)
#             else:
#                 messages.warning(self.request, message)



from django.apps import apps as django_apps
from django.contrib import messages

# from edc_pharmacy.medications import PrescriptionApprovalValidator, \
#     PrescriptionApprovalValidatorError

from .base_action_view import BaseActionView


app_config = django_apps.get_app_config("edc_pharmacy_dashboard")
edc_pharma_app_config = django_apps.get_app_config("edc_pharma")


class ApprovedPrescription(object):
    pass


class ApprovedPrescriptionError(Exception):
    pass


class ApprovePrescriptionView(BaseActionView):

    post_url_name = app_config.listboard_url_name
    listboard_url_name = app_config.prescription_listboard_url_name
    valid_form_actions = ["approve_selected_prescription"]
    prescription_model = django_apps.get_model(
        *edc_pharma_app_config.prescription_model.split(".")
    )

    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self._selected_manifest = None

    def process_form_action(self):
        if not self.selected_items:
            message = "Nothing to do. No items have been selected."
            messages.warning(self.request, message)
        elif self.action == "approve_selected_prescriptions":
            count = 0
            for selected_item in self.selected_items:
                prescription = self.prescription_model_cls.objects.get(pk=selected_item)
                try:
                    ApprovedPrescription(prescription=prescription)
                except ApprovedPrescriptionError as e:
                    messages.error(self.request, str(e))
                    break
                else:
                    count += 1
            if count:
                messages.success(
                    self.request,
                    f"{count}/{len(self.selected_items)} items have been approved.",
                )



# coding=utf-8
from django.apps import AppConfig as DjangoAppConfig


class AppConfig(DjangoAppConfig):
    name = "edc_pharmacy_dashboard"
    verbose_name = "Pharmacy Dashboard"
    include_in_administration_section = False
    admin_site_name = "edc_pharmacy_admin"
    template_path = "edc_pharmacy_dashboard"
    url_namespace = "edc_pharmacy_dashboard"
    dashboard_name = "edc_pharmacy_dashboard"
    base_template_name = "edc_dashboard/base.html"

    dashboard_url_name = f"{url_namespace}:home_url"
    home_url_name = f"{url_namespace}:home_url"
    listboard_url_name = f"{url_namespace}:prescription_listboard_url"

    # dispensing_form_url_name = f'{url_namespace}:dispensing_form_url'
    dispense_listboard_url_name = f"{url_namespace}:dispense_listboard_url"

    prescribe_listboard_template_name = f"{template_path}/prescription_listboard.html"
    prescribe_listboard_url_name = f"{url_namespace}:prescribe_listboard_url"


#     worklist_listboard_template_name = f'{template_path}/worklist_listboard.html'
#     worklist_listboard_url_name = f'{url_namespace}:worklist_listboard_url'
#     appointment_listboard_template_name = f'{template_path}/appointment_listboard.html'
#     appointment_listboard_url_name = f'{url_namespace}:appointment_listboard_url'
#     dispense_print_label_action_url_name = f'{url_namespace}:dispense_print_label_action_url'



from .appointment_listboard_view_filters import AppointmentListboardViewFilters
from .prescription_listboard_view_filters import PrescriptionListboardViewFilters
from .worklist_listboard_view_filters import WorklistListboardViewFilters
